@@ -355,7 +355,7 @@ def filename_handler_meta(fname, filename_handlers):
         _logger.debug(f"Checking filename: {candidate_fname}")
         if os.path.isfile(candidate_fname):
             return candidate_fname
-    _logger.warn(f"Unable to resolve filename: {fname}")
+    _logger.warning(f"Unable to resolve filename: {fname}")
     return fname
 
 
@@ -832,7 +832,7 @@ class URDF:
         origin = np.eye(4) if joint.origin is None else joint.origin
 
         if joint.mimic is not None:
-            mimic_joint_index = self.joint_names.index(joint.mimic.joint)
+            mimic_joint_index = self.actuated_joint_names.index(joint.mimic.joint)
             q = (
                 self._cfg[mimic_joint_index] * joint.mimic.multiplier
                 + joint.mimic.offset
@@ -1004,22 +1004,29 @@ class URDF:
                         new_filename, ignore_broken=True, force="scene"
                     )
 
+                    if "file_path" in new_s.metadata:
+                        for i, (_, geom) in enumerate(new_s.geometry.items()):
+                            if "file_path" not in geom.metadata:
+                                geom.metadata["file_path"] = new_s.metadata["file_path"]
+                                geom.metadata["file_name"] = new_s.metadata["file_name"]
+                                geom.metadata["file_element"] = i
+
                 # scale mesh appropriately
                 if geometry.mesh.scale is not None:
                     if isinstance(geometry.mesh.scale, float):
                         new_s = new_s.scaled(geometry.mesh.scale)
                     elif isinstance(geometry.mesh.scale, np.ndarray):
                         if not np.all(geometry.mesh.scale == geometry.mesh.scale[0]):
-                            _logger.warn(
+                            _logger.warning(
                                 f"Warning: Can't scale axis independently, will use the first entry of '{geometry.mesh.scale}'"
                             )
                         new_s = new_s.scaled(geometry.mesh.scale[0])
                     else:
-                        _logger.warn(
+                        _logger.warning(
                             f"Warning: Can't interpret scale '{geometry.mesh.scale}'"
                         )
             else:
-                _logger.warn(f"Can't find {new_filename}")
+                _logger.warning(f"Can't find {new_filename}")
         return new_s
 
     def _add_geometries_to_scene(
